@@ -5,35 +5,30 @@ use warnings;
 use Carp qw/croak/;
 use XSLoader;
 
-our $VERSION= '4.017_001'; # Don't forget to update the TestCompat set for testing against installed encoders!
-our $XS_VERSION= $VERSION; $VERSION= eval $VERSION;
+our $VERSION = '4.002'; # Don't forget to update the TestCompat set for testing against installed encoders!
+our $XS_VERSION = $VERSION; $VERSION= eval $VERSION;
 
 # not for public consumption, just for testing.
-( my $num_version= $VERSION ) =~ s/_//;
-my $TestCompat= [ map sprintf( "%.2f", $_ / 100 ), reverse( 400 .. int( $num_version * 100 ) ) ]; # compat with 4.00 to ...
-sub _test_compat { return ( @$TestCompat, $VERSION ) }
+(my $num_version = $VERSION) =~ s/_//;
+my $TestCompat = [ map sprintf("%.2f", $_/100), reverse( 400 .. int($num_version * 100) ) ]; # compat with 4.00 to ...
+sub _test_compat { return(@$TestCompat, $VERSION) }
 
 use Exporter 'import';
-our @EXPORT_OK= qw(
-    decode_sereal
-    looks_like_sereal
-    decode_sereal_with_header_data
+our @EXPORT_OK = qw(
+    decode_sereal looks_like_sereal decode_sereal_with_header_data
     scalar_looks_like_sereal
-    sereal_decode_with_object
-    sereal_decode_with_header_with_object
+    sereal_decode_with_object sereal_decode_with_header_with_object
     sereal_decode_only_header_with_object
     sereal_decode_only_header_with_offset_with_object
     sereal_decode_with_header_and_offset_with_object
     sereal_decode_with_offset_with_object
 );
-our %EXPORT_TAGS= ( all => \@EXPORT_OK );
-
+our %EXPORT_TAGS = (all => \@EXPORT_OK);
 # export by default if run from command line
-our @EXPORT= ( ( caller() )[1] eq '-e' ? @EXPORT_OK : () );
+our @EXPORT = ((caller())[1] eq '-e' ? @EXPORT_OK : ());
 
 sub CLONE_SKIP { 1 }
-XSLoader::load( 'Sereal::Decoder', $XS_VERSION );
-#start-no-tidy
+XSLoader::load('Sereal::Decoder', $XS_VERSION);
 use constant #begin generated
 {
   'SRL_F_DECODER_ALIAS_CHECK_FLAGS' => 28672,
@@ -122,44 +117,44 @@ use constant #begin generated
                              undef
                            ]
 }; #end generated
-#end-no-tidy
 
 sub decode_from_file {
-    my ( $self, $file, )= @_;    # pos 3 is "target var" if one is provided
-    $self= $self->new() unless ref $self;
+    my ($self, $file, )= @_; # pos 3 is "target var" if one is provided
     open my $fh, "<", $file
         or die "Failed to open '$file' for read: $!";
-    my $buf= do { local $/; <$fh> };
+    my $buf= do{ local $/; <$fh> };
     close $fh
         or die "Failed to close '$file': $!";
-    if ( wantarray && ( $self->flags & SRL_F_DECODER_DESTRUCTIVE_INCREMENTAL ) ) {
+    if (wantarray && ($self->flags & SRL_F_DECODER_DESTRUCTIVE_INCREMENTAL)) {
         my @ret;
-        while ( length $buf ) {
+        while (length $buf) {
             push @ret, $self->decode($buf);
         }
         return @ret;
     }
-    return $self->decode( $buf, @_ > 2 ? $_[2] : () );
+    return $self->decode($file, $_[2]);
 }
 
 my $flags= sub {
-    my ( $int, $ary )= @_;
-    return map { ( $ary->[$_] and $int & ( 1 << $_ ) ) ? $ary->[$_] : () } ( 0 .. $#$ary );
+    my ($int, $ary)= @_;
+    return map {
+        ($ary->[$_] and $int & (1 << $_)) ? $ary->[$_] : ()
+    } (0..$#$ary);
 };
 
 sub flag_names {
-    my ( $self, $val )= @_;
-    return $flags->( defined $val ? $val : $self->flags, _FLAG_NAME );
+    my ($self, $val)= @_;
+    return $flags->(defined $val ? $val : $self->flags, _FLAG_NAME);
 }
 
 sub flag_names_volatile {
-    my ( $self, $val )= @_;
-    return $flags->( $val // $self->flags, _FLAG_NAME_VOLATILE );
+    my ($self, $val)= @_;
+    return $flags->($val // $self->flags, _FLAG_NAME_VOLATILE);
 }
 
 sub flag_names_static {
-    my ( $self, $val )= @_;
-    return $flags->( $val // $self->flags, _FLAG_NAME_STATIC );
+    my ($self, $val)= @_;
+    return $flags->($val // $self->flags, _FLAG_NAME_STATIC);
 }
 
 1;
@@ -268,30 +263,9 @@ somewhere between 9997 and 10003 nested structures depending on their types.
 If set to a non-zero value (default: 0), then C<Sereal::Decoder> will refuse
 to deserialize any hash/dictionary (or hash-based object) with more than
 that number of entries. This is to be able to respond quickly to any future
-hash-collision attacks on Perl's hash function, and also the memory exhaustion
-attacks on Sereal itself. For a gentle introduction to the topic from the
-cryptographic point of view, see L<http://en.wikipedia.org/wiki/Collision_attack>.
-
-=head3 max_num_array_entries
-
-If set to a non-zero value (default: 0), then C<Sereal::Decoder> will refuse
-to deserialize any array with more than that number of entries.
-This is to be able to respond quickly to any future memory exhaustion attacks on
-Sereal.
-
-=head3 max_string_length
-
-If set to a non-zero value (default: 0), then C<Sereal::Decoder> will refuse
-to deserialize any string with more than that number of characters.
-This is to be able to respond quickly to any future memory exhaustion attacks on
-Sereal.
-
-=head3 max_uncompressed_size
-
-If set to a non-zero value (default: 0), then C<Sereal::Decoder> will refuse
-to deserialize any blob with a size that exceds the value when uncompressed.
-This is to be able to respond quickly to any future memory exhaustion attacks on
-Sereal.
+hash-collision attacks on Perl's hash function. Chances are, you don't want
+or need this. For a gentle introduction to the topic from the cryptographic
+point of view, see L<http://en.wikipedia.org/wiki/Collision_attack>.
 
 =head3 incremental
 
@@ -473,17 +447,6 @@ following example is correct, as only the header is deserialized:
   my $count = $decoder->bytes_consumed;
   # $count is 0
 
-=head2 decode_from_file
-
-    Sereal::Decoder->decode_from_file($file);
-    $decoder->decode_from_file($file);
-
-Read and decode the file specified. If called in list context
-and incremental mode is enabled then decodes all packets
-contained in the file and returns a list, otherwise decodes
-the first (or only) packet in the file. Accepts an optinal
-"target" variable as a second argument.
-
 =head2 looks_like_sereal
 
 Performs some rudimentary check to determine if the argument
@@ -492,7 +455,7 @@ comprehensive and a true result does not mean that the document
 is valid, merely that it appears to be valid. On the other hand
 a false result is always reliable.
 
-The return of this method may be treated as a simple boolean but
+The return of this function may be treated as a simple boolean but
 is in fact a more complex return. When the argument does not
 look anything like a Sereal document then the return is perl's FALSE,
 which has the property of being string equivalent to "" and
@@ -503,7 +466,7 @@ it returns 0 (the number, which is string equivalent to "0"), and
 otherwise returns the protocol version of the document. This means
 you can write something like this:
 
-    $type= Sereal::Decoder->looks_like_sereal($thing);
+    $type= looks_like_sereal($thing);
     if ($type eq '') {
         say "Not a Sereal document";
     } elsif ($type eq '0') {
@@ -518,11 +481,6 @@ version 3 and later. This function checks that the magic string
 corresponds with the reported version number, as well as other
 checks, which may be enhanced in the future.
 
-Note that looks_like_sereal() may be called as a class or object method,
-and may also be called as a single argument function. See the related
-scalar_looks_like_sereal() for a version which may ONLY be called as a
-function, not as a method (and which is typically much faster).
-
 =head1 EXPORTABLE FUNCTIONS
 
 =head2 sereal_decode_with_object
@@ -634,10 +592,6 @@ it cannot reuse the decoder object.
 
 The functional interface that is equivalent to using C<looks_like_sereal>.
 
-Note that this version cannot be called as a method. It is normally executed
-as a custom opcode, as such errors about its usage may be caught at compile
-time, and it should be much faster than looks_like_sereal.
-
 =head1 ROBUSTNESS
 
 This implementation of a Sereal decoder tries to be as robust to invalid
